/*
HTML 5 Audio Button Player
Thomas Weibel Multi & Media
www.thomasweibel.ch
*/

var isPlaying=false; // set variables
var isBlinking=false;
var i, elem, sound, start, wait, blink, resetPlayback;
var background=document.getElementById("background");
var hand=document.getElementById("hand");
var icon=document.getElementById("icon");

elem=document.getElementById("audio"); // set audio id to specific audio name
elem.setAttribute("id", elem.className);
sound=document.getElementById(elem.className);
start=setTimeout (init, 2000); // set initial animation timeout

function init() { // set hand position, indicate playback minutes
	var events=["mousedown","mouseup","touchstart","touchend"]; // set events array
	hand.style.transform="rotate("+360/60*sound.duration/60+"deg)";
	hand.style.webkitTransform="rotate("+360/60*sound.duration/60+"deg)";
	hand.style.transitionDuration="0.5s";
	for (i=0; i<events.length; i++) { // add mouse/touch eventlisteners
		icon.addEventListener(events[i], pauseStop, false);
	}
	clearTimeout(start); // reset initial animation timeout
}

function pauseStop(e) { // timed click/hold detection
	if (wait) {
		playSound();
		clearTimeout(wait);
		wait=false;
	}
	else wait=setTimeout(stopSound, 300);
	e.preventDefault(); // avoid additional event firing on touch-enabled devices
	return false;
}

function playSound() { // play/pause playback, play/pause icon
	if (!isPlaying) {
		sound.play(); // play audio
		clearInterval(blink);
		icon.className="base pause"; // display pause icon
		isPlaying=true;
		displayPlayingTime();
	}
	else {
		sound.pause(); // pause audio
		blink=setInterval(iconBlink, 500); // display blinking play icon
		isPlaying=false;
		displayPauseTime();
	}
	clearTimeout(wait); // clear click/hold detection timeout
	wait=false;
}

function stopSound() { // stop playback, reset display
	sound.pause(); // stop audio
	sound.currentTime=0;
	clearInterval(blink);
	icon.className="base play"; // display static play icon
	isPlaying=false;
	displayReset();
	clearTimeout(wait); // clear click/hold detection timeout
	wait=false;
}

function iconBlink() {
	if (!isBlinking) {
		icon.className="base blink";
		isBlinking=true;
	}
	else {
		icon.className="base play";
		isBlinking=false;
	}
}

function displayPlayingTime() { // display playback time by rotating background dot and hand
	resetPlayback=setTimeout(stopSound, (sound.duration-sound.currentTime)*1000); // set playback timeout
	background.style.transform="rotate(360deg)"; // set rotations and durations
	background.style.webkitTransform="rotate(360deg)";
	background.style.transitionDuration=sound.duration-sound.currentTime+"s";
	hand.style.transform="rotate(0deg)";
	hand.style.webkitTransform="rotate(0deg)";
	hand.style.transitionDuration=sound.duration-sound.currentTime+"s";
}

function displayPauseTime() { // freeze time display on pause
	background.style.transform="rotate("+360/sound.duration*sound.currentTime+"deg)";
	background.style.webkitTransform="rotate("+360/sound.duration*sound.currentTime+"deg)";
	background.style.transitionDuration="0s";
	hand.style.transform="rotate("+360/60*(sound.duration-sound.currentTime)/60+"deg)";
	hand.style.webkitTransform="rotate("+360/60*(sound.duration-sound.currentTime)/60+"deg)";
	hand.style.transitionDuration="0s";
	clearTimeout(resetPlayback); // reset playback timeout
}

function displayReset() { // display reset on end or stop
	background.style.transform="rotate(0deg)";
	background.style.webkitTransform="rotate(0deg)";
	background.style.transitionDuration="0.5s";
	hand.style.transform="rotate("+360/60*sound.duration/60+"deg)";
	hand.style.webkitTransform="rotate("+360/60*sound.duration/60+"deg)";
	hand.style.transitionDuration="0.5s";
	clearTimeout(resetPlayback); // reset playback timeout
}

